


vezeteknevek = ['Kovács', 'Nagy', 'Kiss', 'Tóth', 'Varga', 'Farkas', 'Horváth', 'Szabó', 'Molnár', 'Balázs',
                'Lakatos', 'Takács', 'Papp', 'Katona', 'Szilágyi', 'Balogh', 'Gulyás', 'Szőke', 'Simon', 'Fehér',
                'Barta', 'Császár', 'Sándor', 'Fodor', 'Bakos', 'László', 'Kerekes', 'Fekete', 'Török', 'Pintér',
                'Juhász', 'Gáspár', 'Kis', 'Bognár', 'Hajdu', 'Kónya', 'Kozma', 'Borbély', 'Budai', 'Hegedűs',
                'Ács', 'Bálint', 'Rácz', 'Virág', 'Sipos', 'Kelemen', 'Gál', 'Szőllősi', 'Lengyel', 'Füredi',
                'Magyar', 'Fazekas', 'Antal', 'Bérczes', 'Temesvári', 'Oláh', 'Pál', 'Barna', 'Bajnai', 'Balog',
                'Kocsis', 'Halász', 'Kertész', 'Boros', 'Fekete', 'Bérczi', 'Vincze', 'Dudás', 'Mészáros',
                'Gombos', 'Árkosi', 'Pánczél', 'Karádi', 'Kulcsár', 'Ágoston', 'Pap', 'Pálinkás', 'Csák', 'Bódi',
                'Kerekes', 'Fischer', 'Győri', 'Magyar', 'Péter', 'Fenyő', 'Kocsis', 'Fazekas', 'Kis-Benedek',
                'Bán', 'Bánhidi', 'Kovácsik', 'Kincses', 'Iványi', 'Bertalan', 'Molnár', 'Papp', 'Benedek',
                'Huszár', 'Kis-Gál', 'Németh', 'Somogyi', 'Boda', 'Budai', 'Székely', 'Borsos', 'Czeglédi',
                'Árvai', 'Miklós', 'Füzesi', 'Pap', 'Kisfaludi', 'Pongrácz', 'Tóth', 'Budavári', 'Sajó',
                'Mészáros', 'Lévai', 'Kéri', 'Czakó', 'Csordás', 'Mészáros', 'Bodó', 'Kántor', 'Nagy-Balogh',
                'Szekeres', 'Takács', 'Jakab', 'Herczeg', 'Vajda', 'Gyuris', 'Kincs', 'Végh', 'Lukács', 'Erdélyi',
                'Simon', 'Bárdi', 'Szabó-Balog']

keresztnevek = ['Anna', 'Béla', 'Cecília', 'Dániel', 'Erika', 'Ferenc', 'Géza', 'Hanna', 'István', 'János',
                'Katalin', 'László', 'Mária', 'Nóra', 'Orsolya', 'Péter', 'Róbert', 'Sándor', 'Tamás', 'Zoltán',
                'Ádám', 'Bálint', 'Csongor', 'Dorina', 'Ede', 'Fanni', 'Gergely', 'Hedvig', 'Ildikó', 'Judit',
                'Kitti', 'Levente', 'Máté', 'Noémi', 'Ottó', 'Pál', 'Réka', 'Szilvia', 'Tünde', 'Viktória',
                'Zsolt', 'Ákos', 'Bence', 'Csaba', 'Dóra', 'Eszter', 'Flóra', 'Gábor', 'Hajnalka', 'Izabella',
                'Jázmin', 'Kamilla', 'Lajos', 'Miklós', 'Nikolett', 'Olivér', 'Panna', 'Roland', 'Szabina',
                'Tímea', 'Zsanett', 'Adrián', 'Boglárka', 'Csenge', 'Dávid', 'Emese', 'Fruzsina', 'Gitta', 'Henrik',
                'Ivett', 'Janka', 'Krisztián', 'Lili', 'Márk', 'Norbert', 'Oscar', 'Patrik', 'Rita', 'Sarolta',
                'Tamasin', 'Zsófia', 'Ágota', 'Balázs', 'Cintia', 'Dalma', 'Enikő', 'Fábián', 'Gusztáv', 'Hanga',
                'Ibolya', 'József', 'Károly', 'Lilla', 'Máté', 'Nóel', 'Orsolya', 'Panna', 'Rajmund', 'Szandra',
                'Tamara', 'Zoltán', 'Ágnes', 'Bertalan', 'Csilla', 'Dániel', 'Ede', 'Frida', 'Gyula', 'Hanna-Mária',
                'Imre', 'Júlia', 'Kincső', 'Lívia', 'Mihály', 'Nelli', 'Olga', 'Péter', 'Róza', 'Sára',
                'Tamás', 'Zénó', 'Áron', 'Bálint', 'Csongor', 'Dömötör', 'Elvira', 'Ferenc', 'Gellért', 'Hédi',
                'Igor', 'Jázmin', 'Kamill', 'Larissza', 'Majka', 'Nándor', 'Ottília', 'Petra', 'Rómeó', 'Sascha',
                'Tatjana', 'Zsanett', 'Amanda', 'Balázs', 'Cecil', 'Dzsenna', 'Egon', 'Fanni', 'Gergő','Ábel',
                'Ábrahám', 'Ágota', 'Ágoston', 'Albert', 'Aliz', 'Amanda', 'Ambrus', 'Anasztázia', 'Andor',
                'Andrea', 'Angéla', 'Anna', 'Annabella', 'Annamária', 'Antal', 'Antónia', 'Apollónia', 'Aranka',
                'Ármin', 'Áron', 'Artúr', 'Attila', 'August', 'Aurél', 'Aurelia', 'Auróra', 'Axa'
                'Ágota', 'Áron', 'Ákos', 'Ádám', 'Annamária']
 


from setuptools import setup

setup(
    name='hu_names',
    version='1.0.0',
    description='Hungarian first and second names',
    py_modules=['hu_names'],
    author='Nagy Béla',
    author_email='nagy.belabudapest@gmail.com',
    url='https://github.com/kobanya',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
